@@ -26,13 +26,11 @@ subroutine force()
   call complex_init( forceu )
   call complex_init( forcev )
   call complex_init( forceh )
-!     do j=1,hnt+1
-!        do i=1,nr
-!           forceu(i,j)=(0.0,0.0)
-!           forcev(i,j)=(0.0,0.0)
-!           forceh(i,j)=(0.0,0.0)
-!        end do
-!     end do
+
+  !-- time splitting ѤûѲδ֤ΰ궯
+  call complex_init( termu )
+  call complex_init( termv )
+  call complex_init( termh )
 
 !-- ڥȥѿʬ
 
@@ -459,12 +457,19 @@ subroutine force()
      if(force_flag(8:8)=='o')then  ! Ϸٹ
         do i=2,nr-1
            forceu(i,j)=forceu(i,j)  &
-  &                    -(dhcpdr(i,j))
+  &                    -(g*dhcpdr(i,j))
            forcev(i,j)=forcev(i,j)  &
-  &                    -img*(real(j-1))*hcp_old(i,j)/rs(i)
+  &                    -g*img*(real(j-1))*hcp_old(i,j)/rs(i)
         end do
      end if
 
+  !-- time splitting Ѥΰ궯¸뤿ѿسǼ.
+     do i=2,nr-1
+        termu(i,j)=forceu(i,j)
+        termv(i,j)=forcev(i,j)
+        termh(i,j)=forceh(i,j)
+     end do
+
   end do
 
 !$omp end do
